import Test.Hspec
import ShakespeareJsTest (specs)

main :: IO ()
main = hspec specs
